==> Rdistance_1.2.1.tar.gz: Rdistance/man/coef.dfunc.Rd <==
\name{coef.dfunc}
\alias{coef.dfunc}

\title{Coefficients of an estimated detection function}

\description{Extract the coefficients and estimated parameters (if any) from 
a estimated detection function object.}

\usage{
\method{coef}{dfunc}(object, \dots)
}

\arguments{
  \item{object}{An estimated distance function object.  An estimated distance 
  function object has class 'dfunc', and is usually produced by a call to 
  \code{F.dfunc.estim}. }
  
  \item{\dots}{Required for compatability with the general \code{coef} method.  Any 
  extra arguments to this function are ignored. }
}

\details{
This is an extractor function for the parameters of an estimated detection function. 
This function is equivalent to \code{obj$parameters} for classical detection functions. 
}

\value{
The estimated parameter vector for the detection function. Length and interpretation of values 
in this vector vary depending on the form of the detection function and expansion terms.
}


\author{
Trent McDonald, WEST Inc.,  \email{tmcdonald@west-inc.com}
}


\seealso{
\code{\link{AIC}}, \code{\link{F.dfunc.estim}}
}

\examples{
# Load the example sparrows distances dataset from package
data(sparrow.dists)

# Compute perpendicular, off-transect distances from the observer's sight distance and angle
sparrow.dists$dists <- perp.dists(obs.dist=sparrow.dists$sightdist,
                                  obs.angle=sparrow.dists$sightangle)

# Fit detection function object
dfunc <- F.dfunc.estim(sparrow.dists, w.hi=150)

# Extract the coefficient(s)
coef(dfunc)
}

\keyword{ model }

==> Rdistance_1.2.2.tar.gz: Rdistance/man/coef.dfunc.Rd <==
\name{coef.dfunc}
\alias{coef.dfunc}

\title{Coefficients of an estimated detection function}

\description{Extract the coefficients and estimated parameters (if any) from 
a estimated detection function object.}

\usage{
\method{coef}{dfunc}(object, \dots)
}

\arguments{
  \item{object}{An estimated distance function object.  An estimated distance 
  function object has class 'dfunc', and is usually produced by a call to 
  \code{F.dfunc.estim}. }
  
  \item{\dots}{Required for compatability with the general \code{coef} method.  Any 
  extra arguments to this function are ignored. }
}

\details{
This is an extractor function for the parameters of an estimated detection function. 
This function is equivalent to \code{obj$parameters} for classical detection functions. 
}

\value{
The estimated parameter vector for the detection function. Length and interpretation of values 
in this vector vary depending on the form of the detection function and expansion terms.
}


\author{
Trent McDonald, WEST Inc.,  \email{tmcdonald@west-inc.com}
}


\seealso{
\code{\link{AIC}}, \code{\link{F.dfunc.estim}}
}

\examples{
# Load the example dataset for sparrow detections from package
data(sparrow.detections)

# Compute perpendicular, off-transect distances from the observer's sight distance and angle
sparrow.detections$dist <- perp.dists(obs.dist=sparrow.detections$sightdist,
                                  obs.angle=sparrow.detections$sightangle)

# Fit detection function object
dfunc <- F.dfunc.estim(sparrow.detections, w.hi=150)

# Extract the coefficient(s)
coef(dfunc)
}

\keyword{ model }
